Trait game_grid::GridPosition
source · Expand description
Trait to implement a type that can be used as a grid position.
This trait provides access to the x and y coordinates as well as a constructor used by the grid internaly.
Trait to implement a type that can be used as a grid position.
This trait provides access to the x and y coordinates as well as a constructor used by the grid internaly.